# Contributing to PDBe MCP Server

Thank you for your interest in contributing to the PDBe MCP Server project!

## How to Contribute

- Fork the repository and create your branch from `main`.
- Make your changes with clear commit messages.
- Ensure your code follows the style and type hints used in the project.
- Add or update documentation and tests as needed.
- Open a pull request describing your changes.

## Code of Conduct

Please be respectful and considerate in your communications and contributions.

## Initial Work

This project was initially developed by:

**Sreenath Sasidharan Nair** (<sreenath@ebi.ac.uk>)
